@@ -33,8 +33,12 @@ extern dofunction *action;
 void extracthalf(const char *debar, const char *directory,
                  const char *taroption, int admininfo);
 
+extern char *compression;
+
 #define DEBMAGIC     "!<arch>\ndebian-binary   "
-#define ADMINMEMBER  "control.tar.gz  "
-#define DATAMEMBER   "data.tar.gz     "
+#define ADMINMEMBER		"control.tar.gz  "
+#define ADMINMEMBER_COMPAT	"control.tar.gz/ "
+#define DATAMEMBER		"data.tar.gz     "
+#define DATAMEMBER_COMPAT	"data.tar.gz/    "
 
 #endif /* DPKG_DEB_H */
