@@ -21,7 +21,6 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <curses.h>
 #include <assert.h>
 
 extern "C" {
@@ -205,13 +204,13 @@ int packagelist::resolvedepcon(dependency *depends) {
 
   if (depdebug && debug) {
     fprintf(debug,"packagelist[%p]::resolvedepcon([%p] %s --%s-->",
-            this,depends,depends->up->name,relatestrings[depends->type]);
+          this,depends,depends->up->name,gettext(relatestrings[depends->type]));
     for (possi=depends->list; possi; possi=possi->next)
       fprintf(debug," %s",possi->ed->name);
     fprintf(debug,"); (ing)->want=%s\n",
             depends->up->clientdata
-            ? wantstrings[depends->up->clientdata->suggested]
-            : "(no clientdata)");
+            ? gettext(wantstrings[depends->up->clientdata->suggested])
+            : _("(no clientdata)"));
   }
   
   if (!depends->up->clientdata) return 0;
@@ -221,11 +220,49 @@ int packagelist::resolvedepcon(dependency *depends) {
   case dep_provides:
   case dep_replaces:
     return 0;
-    
+
+  case dep_enhances:
+    return 0;
+
   case dep_suggests:
-    if (0) return 0; /* fixme: configurable */
-    // fall through ...
   case dep_recommends:
+#if 0
+    if (would_like_to_install(depends->up->clientdata->selected,depends->up) <= 0)
+      return 0;
+
+    fixbyupgrade= 0;
+    
+    for (possi= depends->list;
+         possi && !deppossatisfied(possi,&fixbyupgrade);
+         possi= possi->next);
+    if (depdebug && debug)
+      fprintf(debug,"packagelist[%p]::resolvedepcon([%p]): depends found %s\n",
+              this,depends,
+              possi ? possi->ed->name : _("[none]"));
+    if (possi) return 0;
+
+    // For a recommends we default to selecting the package
+    if (depends->type==dep_recommends)  {
+      for (possi=depends->list; possi; possi= possi->next) {
+        pkginfo::pkgwant nw;
+	if (!possi->ed->clientdata) continue;
+	nw= reallywant(pkginfo::want_install, possi->ed->clientdata);
+	if (possi->ed->clientdata->selected == nw ||
+		(possi->ed->clientdata->selected == pkginfo::want_purge &&
+		 nw==pkginfo::want_deinstall))
+	    ; // already in the state we want it, so do nothing
+	else {
+	  possi->ed->clientdata->suggested = possi->ed->clientdata->selected = nw;
+	  possi->ed->clientdata->spriority= sp_selecting;
+	}
+      }
+    }
+    
+    // Ensures all in the recursive list; adds info strings; ups priorities
+    r= add(depends, depends->type == dep_suggests ? dp_may : dp_must);
+
+    return r;
+#endif
   case dep_depends:
   case dep_predepends:
 
@@ -240,7 +277,7 @@ int packagelist::resolvedepcon(dependency *depends) {
     if (depdebug && debug)
       fprintf(debug,"packagelist[%p]::resolvedepcon([%p]): depends found %s\n",
               this,depends,
-              possi ? possi->ed->name : "[none]");
+              possi ? possi->ed->name : _("[none]"));
     if (possi) return 0;
 
     // Ensures all in the recursive list; adds info strings; ups priorities
@@ -333,6 +370,8 @@ int packagelist::resolvedepcon(dependency *depends) {
   default:
     internerr("unknown deptype");
   }
+  /* never reached, make gcc happy */
+  return 1;
 }
 
 int packagelist::deppossatisfied(deppossi *possi, perpackagestate **fixbyupgrade) {
