@@ -21,7 +21,6 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <curses.h>
 #include <assert.h>
 #include <ctype.h>
 
@@ -66,10 +65,10 @@ const struct helpmenuentry *packagelist::helpmenulist() {
 int packagelist::itr_recursive() { return recursive; }
 
 const packagelist::infotype packagelist::infoinfos[]= {
-  { itr_recursive,     itd_relations         },
-  { 0,                 itd_description       },
-  { 0,                 itd_statuscontrol     },
-  { 0,                 itd_availablecontrol  },
+  { &packagelist::itr_recursive,     &packagelist::itd_relations         },
+  { 0,                               &packagelist::itd_description       },
+  { 0,                               &packagelist::itd_statuscontrol     },
+  { 0,                               &packagelist::itd_availablecontrol  },
   { 0,                 0                     }
 };
 
@@ -78,7 +77,7 @@ const packagelist::infotype *const packagelist::baseinfo= infoinfos;
 void packagelist::severalinfoblurb(const char *whatinfoline) {
   whatinfovb(whatinfoline);
   varbuf vb;
-  vb("The line you have highlighted represents many packages; "
+  vb(_("The line you have highlighted represents many packages; "
      "if you ask to install, remove, hold, &c it you will affect all "
      "the packages which match the criterion shown.\n"
      "\n"
@@ -86,29 +85,29 @@ void packagelist::severalinfoblurb(const char *whatinfoline) {
      "you will see information about that package displayed here."
      "\n"
      "You can use `o' and `O' to change the sort order and give yourself "
-     "the opportunity to mark packages in different kinds of groups.");
+     "the opportunity to mark packages in different kinds of groups."));
   wordwrapinfo(0,vb.string());
 }
 
 void packagelist::itd_relations() {
   if (table[cursorline]->pkg->name) {
-    whatinfovb("interrelationships affecting ");
+    whatinfovb(_("interrelationships affecting "));
     whatinfovb(table[cursorline]->pkg->name);
     if (debug) fprintf(debug,"packagelist[%p]::idt_relations(); `%s'\n",
                        this,table[cursorline]->relations.string());
     waddstr(infopad,table[cursorline]->relations.string());
   } else {
-    severalinfoblurb("interrelationships");
+    severalinfoblurb(_("interrelationships"));
   }
 }
 
 void packagelist::itd_description() {
   if (table[cursorline]->pkg->name) {
-    whatinfovb("description of ");
+    whatinfovb(_("description of "));
     whatinfovb(table[cursorline]->pkg->name);
 
     const char *m= table[cursorline]->pkg->available.description;
-    if (!m || !*m) m= "no description available.";
+    if (!m || !*m) m= _("no description available.");
     const char *p= strchr(m,'\n');
     int l= p ? (int)(p-m) : strlen(m);
     wattrset(infopad,info_headattr);
@@ -121,16 +120,16 @@ void packagelist::itd_description() {
       wordwrapinfo(1,++p);
     }
   } else {
-    severalinfoblurb("description");
+    severalinfoblurb(_("description"));
   }
 }
 
 void packagelist::itd_statuscontrol() {
   werase(infopad);
   if (!table[cursorline]->pkg->name) {
-    severalinfoblurb("currently installed control info");
+    severalinfoblurb(_("currently installed control info"));
   } else {
-    whatinfovb("installed control info for ");
+    whatinfovb(_("installed control info for "));
     whatinfovb(table[cursorline]->pkg->name);
     varbuf vb;
     varbufrecord(&vb,table[cursorline]->pkg,&table[cursorline]->pkg->installed);
@@ -144,9 +143,9 @@ void packagelist::itd_statuscontrol() {
 void packagelist::itd_availablecontrol() {
   werase(infopad);
   if (!table[cursorline]->pkg->name) {
-    severalinfoblurb("available version of control file info");
+    severalinfoblurb(_("available version of control file info"));
   } else {
-    whatinfovb("available version of control info for ");
+    whatinfovb(_("available version of control info for "));
     whatinfovb(table[cursorline]->pkg->name);
     varbuf vb;
     varbufrecord(&vb,table[cursorline]->pkg,&table[cursorline]->pkg->available);
