@@ -21,14 +21,13 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <ncurses.h>
 #include <assert.h>
-#include <signal.h>
+#include <errno.h>
 
 extern "C" {
-#include "config.h"
-#include "dpkg.h"
-#include "dpkg-db.h"
+#include <config.h>
+#include <dpkg.h>
+#include <dpkg-db.h>
 }
 #include "dselect.h"
 #include "bindings.h"
@@ -78,6 +77,8 @@ int packagelist::compareentries(struct perpackagestate *a,
   default:
     internerr("unsorted or unknown in compareentries");
   }
+  /* never reached, make gcc happy */
+  return 1;
 }
 
 void packagelist::discardheadings() {
@@ -116,8 +117,8 @@ void packagelist::addheading(enum ssavailval ssavail,
   
   if (debug) fprintf(debug,"packagelist[%p]::addheading(%d,%d,%d,%s,%s)\n",
                      this,ssavail,ssstate,priority,
-                     otherpriority ? otherpriority : "<null>",
-                     section ? section : "<null>");
+                     otherpriority ? otherpriority : _("<null>"),
+                     section ? section : _("<null>"));
 
   struct pkginfo *newhead= new pkginfo;
   newhead->name= 0;
@@ -489,6 +490,8 @@ pkginfo **packagelist::display() {
 
   setupsigwinch();
   startdisplay();
+
+  if (!expertmode)
   displayhelp(helpmenulist(),'i');
 
   if (debug) fprintf(debug,"packagelist[%p]::display() entering loop\n",this);
@@ -497,7 +500,9 @@ pkginfo **packagelist::display() {
     if (doupdate() == ERR) ohshite("doupdate failed");
     signallist= this;
     if (sigprocmask(SIG_UNBLOCK,&sigwinchset,0)) ohshite("failed to unblock SIGWINCH");
-    response= getch();
+    do
+      response= getch();
+    while (response == ERR && errno == EINTR);
     if (sigprocmask(SIG_BLOCK,&sigwinchset,0)) ohshite("failed to re-block SIGWINCH");
     if (response == ERR) ohshite("getch failed");
     interp= (*bindings)(response);
