@@ -21,9 +21,7 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <curses.h>
 #include <assert.h>
-#include <signal.h>
 
 extern "C" {
 #include <config.h>
@@ -54,14 +52,14 @@ void packagelist::add(pkginfo *pkg) {
 
 void packagelist::add(pkginfo *pkg, pkginfo::pkgwant nw) {
   if (debug) fprintf(debug,"packagelist[%p]::add(pkginfo %s, %s)\n",
-                     this,pkg->name,wantstrings[nw]);
+                     this,pkg->name,gettext(wantstrings[nw]));
   add(pkg);  if (!pkg->clientdata) return;
   pkg->clientdata->direct= nw;
   selpriority np;
   np= would_like_to_install(nw,pkg) ? sp_selecting : sp_deselecting;
   if (pkg->clientdata->spriority > np) return;
   if (debug) fprintf(debug,"packagelist[%p]::add(pkginfo %s, %s) setting\n",
-                     this,pkg->name,wantstrings[nw]);
+                     this,pkg->name,gettext(wantstrings[nw]));
   pkg->clientdata->suggested= pkg->clientdata->selected= nw;
   pkg->clientdata->spriority= np;
     
@@ -102,7 +100,7 @@ void packagelist::addunavailable(deppossi *possi) {
 
   varbuf& vb= possi->up->up->clientdata->relations;
   vb(possi->ed->name);
-  vb(" does not appear to be available\n");
+  vb(_(" does not appear to be available\n"));
 }
 
 int packagelist::add(dependency *depends, showpriority displayimportance) {
@@ -114,12 +112,12 @@ int packagelist::add(dependency *depends, showpriority displayimportance) {
   varbuf info;
   info(depends->up->name);
   info(' ');
-  info(relatestrings[depends->type]);
+  info(gettext(relatestrings[depends->type]));
   info(' ');
   deppossi *possi;
   for (possi=depends->list;
        possi;
-       possi=possi->next, comma=(possi && possi->next ? ", " : " or ")) {
+       possi=possi->next, comma=(possi && possi->next ? ", " : _(" or "))) {
     info(comma);
     info(possi->ed->name);
     if (possi->verrel != dvr_none) {
