@@ -60,33 +60,41 @@ static void limiteddescription(struct pkginfo *pkg, int maxl,
   *pdesc_r=pdesc; *l_r=l;
 }
 
-static int getttywidth() {
+static int getwidth() {
   int fd;
   int res;
   struct winsize ws;
+  const char* columns;
 
-  if ((fd=open("/dev/tty",O_RDONLY))!=-1) {
-    if (ioctl(fd, TIOCGWINSZ, &ws)==-1)
-      ws.ws_col=80;
-    close(fd);
-    return ws.ws_col;
-  } else
-    return 80;
+  if ((columns=getenv("COLUMNS")) && ((res=atoi(columns))>0))
+    ws.ws_col=res;
+  else if (!isatty(1))
+    ws.ws_col=80;
+  else {
+    if ((fd=open("/dev/tty",O_RDONLY))!=-1) {
+      if (ioctl(fd, TIOCGWINSZ, &ws)==-1)
+        ws.ws_col=80;
+      close(fd);
+    }
+  }
+  return ws.ws_col;
 }
 
 static void list1package(struct pkginfo *pkg, int *head) {
   int l,w;
-  int nw,vw,dw;
+  static int nw,vw,dw;
   const char *pdesc;
-  char format[80];
+  static char format[80]   = "";
     
-  w=getttywidth()-80;	/* get spare width */
-  if (w<0) w=0;		/* lets not try to deal with terminals that are too small */
-  w>>=2;		/* halve that so we can add that to the both the name and description */
-  nw=(14+w);		/* name width */
-  vw=(14+w);		/* version width */
-  dw=(44+(2*w));	/* description width */
-  sprintf(format,"%%c%%c%%c %%-%d.%ds %%-%d.%ds %%.*s\n", nw, nw, vw, vw);
+  if (format[0]==0) {
+    w=getwidth()-80;	/* get spare width */
+    if (w<0) w=0;		/* lets not try to deal with terminals that are too small */
+    w>>=2;		/* halve that so we can add that to the both the name and description */
+    nw=(14+w);		/* name width */
+    vw=(14+w);		/* version width */
+    dw=(44+(2*w));	/* description width */
+    sprintf(format,"%%c%%c%%c %%-%d.%ds %%-%d.%ds %%.*s\n", nw, nw, vw, vw);
+  }
 
   if (!*head) {
     fputs(_("\
@@ -474,7 +482,7 @@ void enqperpackage(const char *const *argv) {
               if (!namenode->divert->pkg) printf(_("locally diverted"));
               else if (pkg == namenode->divert->pkg) printf(_("package diverts others"));
               else printf(_("diverted by %s"),namenode->divert->pkg->name);
-              printf(" to: %s\n",namenode->divert->useinstead->name);
+              printf(_(" to: %s\n"),namenode->divert->useinstead->name);
             }
             file= file->next;
           }
