@@ -32,105 +32,111 @@
 #include <limits.h>
 #include <ctype.h>
 
-#include "config.h"
-#include "dpkg.h"
-#include "dpkg-db.h"
-#include "version.h"
-#include "myopt.h"
+#include <config.h>
+#include <dpkg.h>
+#include <dpkg-db.h>
+#include <version.h>
+#include <myopt.h>
 
 #include "main.h"
 
 static void printversion(void) {
-  if (!fputs("Debian Linux `" DPKG "' package management program version "
-              DPKG_VERSION_ARCH ".\n"
-             "Copyright 1994-1996 Ian Jackson, Bruce Perens.  This is free software;\n"
-             "see the GNU General Public Licence version 2 or later for copying\n"
-             "conditions.  There is NO warranty.  See dpkg --licence for details.\n",
-             stdout)) werr("stdout");
+  if (fputs(_("Debian GNU/Linux `"), stdout) < 0) werr("stdout");
+  if (fputs(DPKG, stdout) < 0) werr("stdout");
+  if (fputs(_("' package management program version "), stdout) < 0) werr("stdout");
+  if (fputs( DPKG_VERSION_ARCH ".\n", stdout) < 0) werr("stdout");
+  if (fputs(_( "This is free software; see the GNU General Public Licence version 2 or\n"
+		"later for copying conditions.  There is NO warranty.\n"
+		"See dpkg --licence for copyright and license details.\n"),
+		 stdout) < 0) werr("stdout");
 }
 /*
    options that need fixing:
-  " DPKG " --yet-to-unpack                 \n\
+  dpkg --yet-to-unpack                 \n\
   */
 static void usage(void) {
-  if (!fputs("\
+  if (fprintf (stdout, _("\
 Usage: \n\
-  " DPKG " -i|--install      <.deb file name> ... | -R|--recursive <dir> ...\n\
-  " DPKG " --unpack          <.deb file name> ... | -R|--recursive <dir> ...\n\
-  " DPKG " -A|--record-avail <.deb file name> ... | -R|--recursive <dir> ...\n\
-  " DPKG " --configure           <package name> ... | -a|--pending\n\
-  " DPKG " -r|--remove | --purge <package name> ... | -a|--pending\n\
-  " DPKG " --get-selections [<pattern> ...]   get list of selections to stdout\n\
-  " DPKG " --set-selections                   set package selections from stdin\n\
-  " DPKG " --update-avail <Packages-file>     replace available packages info\n\
-  " DPKG " --merge-avail <Packages-file>      merge with info from file\n\
-  " DPKG " --clear-avail                      erase existing available info\n\
-  " DPKG " --forget-old-unavail               forget uninstalled unavailable pkgs\n\
-  " DPKG " -s|--status <package-name> ...     display package status details\n\
-  " DPKG " --print-avail <package-name> ...   display available version details\n\
-  " DPKG " -L|--listfiles <package-name> ...  list files `owned' by package(s)\n\
-  " DPKG " -l|--list [<pattern> ...]          list packages concisely\n\
-  " DPKG " -S|--search <pattern> ...          find package(s) owning file(s)\n\
-  " DPKG " -C|--audit                         check for broken package(s)\n\
-  " DPKG " --print-architecture               print target architecture (uses GCC)\n\
-  " DPKG " --print-gnu-build-architecture     print GNU version of target arch\n\
-  " DPKG " --print-installation-architecture  print host architecture (for inst'n)\n\
-  " DPKG " --compare-versions <a> <rel> <b>   compare version numbers - see below\n\
-  " DPKG " --help | --version                 show this help / version number\n\
-  " DPKG " --force-help | -Dh|--debug=help    help on forcing resp. debugging\n\
-  " DPKG " --licence                          print copyright licencing terms\n\
+  dpkg -i|--install      <.deb file name> ... | -R|--recursive <dir> ...\n\
+  dpkg --unpack          <.deb file name> ... | -R|--recursive <dir> ...\n\
+  dpkg -A|--record-avail <.deb file name> ... | -R|--recursive <dir> ...\n\
+  dpkg --configure              <package name> ... | -a|--pending\n\
+  dpkg -r|--remove | -P|--purge <package name> ... | -a|--pending\n\
+  dpkg --get-selections [<pattern> ...]    get list of selections to stdout\n\
+  dpkg --set-selections                    set package selections from stdin\n\
+  dpkg --update-avail <Packages-file>      replace available packages info\n\
+  dpkg --merge-avail <Packages-file>       merge with info from file\n\
+  dpkg --clear-avail                       erase existing available info\n\
+  dpkg --forget-old-unavail                forget uninstalled unavailable pkgs\n\
+  dpkg -s|--status <package-name> ...      display package status details\n\
+  dpkg -p|--print-avail <package-name> ... display available version details\n\
+  dpkg -L|--listfiles <package-name> ...   list files `owned' by package(s)\n\
+  dpkg -l|--list [<pattern> ...]           list packages concisely\n\
+  dpkg -S|--search <pattern> ...           find package(s) owning file(s)\n\
+  dpkg -C|--audit                          check for broken package(s)\n\
+  dpkg --print-architecture                print target architecture (uses GCC)\n\
+  dpkg --print-gnu-build-architecture      print GNU version of target arch\n\
+  dpkg --print-installation-architecture   print host architecture (for inst'n)\n\
+  dpkg --compare-versions <a> <rel> <b>    compare version numbers - see below\n\
+  dpkg --help | --version                  show this help / version number\n\
+  dpkg --force-help | -Dh|--debug=help     help on forcing resp. debugging\n\
+  dpkg --licence                           print copyright licensing terms\n\
 \n\
-Use " DPKG " -b|--build|-c|--contents|-e|--control|-I|--info|-f|--field|\n\
- -x|--extract|-X|--vextract|--fsys-tarfile  on archives (type " BACKEND " --help.)\n\
+Use dpkg -b|--build|-c|--contents|-e|--control|-I|--info|-f|--field|\n\
+ -x|--extract|-X|--vextract|--fsys-tarfile  on archives (type %s --help.)\n\
 \n\
-For internal use: " DPKG " --assert-support-predepends | --predep-package |\n\
-  --assert-working-epoch\n\
+For internal use: dpkg --assert-support-predepends | --predep-package |\n\
+  --assert-working-epoch | --assert-long-filenames | --assert-multi-conrep\n\
 \n\
-Options:
-  --admindir=<directory>     Use <directory> instead of " ADMINDIR "\n\
+Options:\n\
+  --admindir=<directory>     Use <directory> instead of %s\n\
   --root=<directory>         Install on alternative system rooted elsewhere\n\
   --instdir=<directory>      Change inst'n root without changing admin dir\n\
   -O|--selected-only         Skip packages not selected for install/upgrade\n\
   -E|--skip-same-version     Skip packages whose same version is installed\n\
-  -G=--refuse-downgrade      Skip packages with earlier version than installed\n\
+  -G|--refuse-downgrade      Skip packages with earlier version than installed\n\
   -B|--auto-deconfigure      Install even if it would break some other package\n\
   --largemem | --smallmem    Optimise for large (>4Mb) or small (<4Mb) RAM use\n\
   --no-act                   Just say what we would do - don't do it\n\
-  -D|--debug=<octal>         Enable debugging - see -Dhelp or --debug=help
+  -D|--debug=<octal>         Enable debugging - see -Dhelp or --debug=help\n\
   --ignore-depends=<package>,... Ignore dependencies involving <package>\n\
   --force-...                    Override problems - see --force-help\n\
   --no-force-...|--refuse-...    Stop when problems encountered\n\
+  dpkg --abort-after <n>     abort after encountering <n> errors\n\
 \n\
 Comparison operators for --compare-versions are:\n\
  lt le eq ne ge gt       (treat no version as earlier than any version);\n\
  lt-nl le-nl ge-nl gt-nl (treat no version as later than any version);\n\
  < << <= = >= >> >       (only for compatibility with control file syntax).\n\
 \n\
-Use `" DSELECT "' for user-friendly package management.\n",
-             stdout)) werr("stdout");
+Use `dselect' for user-friendly package management.\n"),
+	    BACKEND, ADMINDIR) < 0) werr ("stdout");
 }
 
-const char thisname[]= DPKG;
+const char thisname[]= "dpkg";
 const char architecture[]= ARCHITECTURE;
-const char printforhelp[]= "\
-Type " DPKG " --help for help about installing and deinstalling packages [*];\n\
-Use " DSELECT " for user-friendly package management;\n\
-Type " DPKG " -Dhelp for a list of " DPKG " debug flag values;\n\
-Type " DPKG " --force-help for a list of forcing options;\n\
-Type " BACKEND " --help for help about manipulating *.deb files;\n\
-Type " DPKG " --licence for copyright licence and lack of warranty (GNU GPL) [*].\n\
+const char printforhelp[]= N_("\
+Type dpkg --help for help about installing and deinstalling packages [*];\n\
+Use dselect for user-friendly package management;\n\
+Type dpkg -Dhelp for a list of dpkg debug flag values;\n\
+Type dpkg --force-help for a list of forcing options;\n\
+Type dpkg-deb --help for help about manipulating *.deb files;\n\
+Type dpkg --licence for copyright licence and lack of warranty (GNU GPL) [*].\n\
 \n\
-Options marked [*] produce a lot of output - pipe it through `less' or `more' !";
+Options marked [*] produce a lot of output - pipe it through `less' or `more' !");
 
 const struct cmdinfo *cipaction= 0;
 int f_pending=0, f_recursive=0, f_alsoselect=1, f_skipsame=0, f_noact=0;
 int f_autodeconf=0, f_largemem=0;
 unsigned long f_debug=0;
+/* Change fc_overwrite to 1 to enable force-overwrite by default */
 int fc_downgrade=1, fc_configureany=0, fc_hold=0, fc_removereinstreq=0, fc_overwrite=1;
 int fc_removeessential=0, fc_conflicts=0, fc_depends=0, fc_dependsversion=0;
 int fc_autoselect=1, fc_badpath=0, fc_overwritediverted=0, fc_architecture=0;
-int fc_nonroot=0, fc_overwritedir=0;
+int fc_nonroot=0, fc_overwritedir=0, fc_conff_new=0, fc_conff_miss=0;
+int fc_conff_old=0, fc_conff_def=0;
 
+int errabort = 50;
 const char *admindir= ADMINDIR;
 const char *instdir= "";
 struct packageinlist *ignoredependss=0;
@@ -145,6 +151,10 @@ static const struct forceinfo {
   { "remove-reinstreq",    &fc_removereinstreq          },
   { "remove-essential",    &fc_removeessential          },
   { "conflicts",           &fc_conflicts                },
+  { "confnew",             &fc_conff_new                },
+  { "confold",             &fc_conff_old                },
+  { "confdef",             &fc_conff_def                },
+  { "confmiss",            &fc_conff_miss               },
   { "depends",             &fc_depends                  },
   { "depends-version",     &fc_dependsversion           },
   { "auto-select",         &fc_autoselect               },
@@ -166,7 +176,7 @@ static void versiononly(const struct cmdinfo *cip, const char *value) {
 
 static void setaction(const struct cmdinfo *cip, const char *value) {
   if (cipaction)
-    badusage("conflicting actions --%s and --%s",cip->olong,cipaction->olong);
+    badusage(_("conflicting actions --%s and --%s"),cip->olong,cipaction->olong);
   cipaction= cip;
 }
 
@@ -174,8 +184,8 @@ static void setdebug(const struct cmdinfo *cpi, const char *value) {
   char *endp;
 
   if (*value == 'h') {
-    if (!fputs(
-DPKG " debugging option, --debug=<octal> or -D<octal>:\n\n\
+    if (printf(
+_("%s debugging option, --debug=<octal> or -D<octal>:\n\n\
  number  ref. in source   description\n\
       1   general           Generally helpful progress information\n\
       2   scripts           Invocation and status of maintainer scripts\n\
@@ -188,13 +198,13 @@ DPKG " debugging option, --debug=<octal> or -D<octal>:\n\n\
    1000   veryverbose       Lots of drivel about eg the dpkg/info directory\n\
    2000   stupidlyverbose   Insane amounts of drivel\n\n\
 Debugging options are be mixed using bitwise-or.\n\
-Note that the meanings and values are subject to change.\n",
-             stderr)) werr("stderr");
+Note that the meanings and values are subject to change.\n"),
+             DPKG) < 0) werr("stdout");
     exit(0);
   }
   
   f_debug= strtoul(value,&endp,8);
-  if (*endp) badusage("--debug requires an octal argument");
+  if (*endp) badusage(_("--debug requires an octal argument"));
 }
 
 static void setroot(const struct cmdinfo *cip, const char *value) {
@@ -218,14 +228,14 @@ static void ignoredepends(const struct cmdinfo *cip, const char *value) {
     if (*p != ',') continue;
     *p++= 0;
     if (!*p || *p==',' || p==copy+1)
-      badusage("null package name in --ignore-depends comma-separated list `%.250s'",
+      badusage(_("null package name in --ignore-depends comma-separated list `%.250s'"),
                value);
   }
   p= copy;
   while (*p) {
     pnerr= illegal_packagename(value,0);
-    if (pnerr) ohshite("--ignore-depends requires a legal package name. "
-                       "`%.250s' is not; %s", value, pnerr);
+    if (pnerr) ohshite(_("--ignore-depends requires a legal package name. "
+                       "`%.250s' is not; %s"), value, pnerr);
     ni= m_malloc(sizeof(struct packageinlist));
     ni->pkg= findpackage(value);
     ni->next= ignoredependss;
@@ -234,27 +244,43 @@ static void ignoredepends(const struct cmdinfo *cip, const char *value) {
   }
 }
 
+static void setinteger(const struct cmdinfo *cip, const char *value) {
+  unsigned long v;
+  char *ep;
+
+  v= strtoul(value,&ep,0);
+  if (*ep || v > INT_MAX)
+    badusage(_("invalid integer for --%s: `%.250s'"),cip->olong,value);
+  *cip->iassignto= v;
+}
+
 static void setforce(const struct cmdinfo *cip, const char *value) {
   const char *comma;
   int l;
   const struct forceinfo *fip;
 
   if (!strcmp(value,"help")) {
-    if (!fputs(
-DPKG " forcing options - control behaviour when problems found:\n\
+    if (printf(_("%s forcing options - control behaviour when problems found:\n\
   warn but continue:  --force-<thing>,<thing>,...\n\
   stop with error:    --refuse-<thing>,<thing>,... | --no-force-<thing>,...\n\
  Forcing things:\n\
   auto-select [*]        (De)select packages to install (remove) them\n\
-  dowgrade [*]           Replace a package with a lower version\n\
+  downgrade [*]          Replace a package with a lower version\n\
   configure-any          Configure any package which may help this one\n\
   hold                   Process incidental packages even when on hold\n\
   bad-path               PATH is missing important programs, problems likely\n\
   not-root               Try to (de)install things even when not root\n\
-  overwrite [*]          Overwrite a file from one package with another\n\
+  overwrite[*]           Overwrite a file from one package with another\n\
   overwrite-diverted     Overwrite a diverted file with an undiverted version\n\
   depends-version [!]    Turn dependency version problems into warnings\n\
   depends [!]            Turn all dependency problems into warnings\n\
+  confnew [!]            Always use the new config files, don't prompt\n\
+  confold [!]            Always use the old config files, don't prompt\n\
+  confdef [!]            Use the default option for new config files if one\n\
+                         is available, don't prompt. If no default can be found,\n\
+                         you will be prompted unless one of the confold or\n\
+                         confnew options is also given\n\
+  confmiss [!]           Always install missing config files\n\
   conflicts [!]          Allow installation of conflicting packages\n\
   architecture [!]       Process even packages with wrong architecture\n\
   overwrite-dir [!]      Overwrite one package's directory with another's file\n\
@@ -262,8 +288,8 @@ DPKG " forcing options - control behaviour when problems found:\n\
   remove-essential [!]   Remove an essential package\n\
 \n\
 WARNING - use of options marked [!] can seriously damage your installation.\n\
-Forcing options marked [*] are enabled by default.\n",
-               stderr)) werr("stderr");
+Forcing options marked [*] are enabled by default.\n"),
+               DPKG) < 0) werr("stdout");
     exit(0);
   }
 
@@ -273,7 +299,7 @@ Forcing options marked [*] are enabled by default.\n",
     for (fip=forceinfos; fip->name; fip++)
       if (!strncmp(fip->name,value,l) && strlen(fip->name)==l) break;
     if (!fip->name)
-      badusage("unknown force/refuse option `%.*s'", l<250 ? l : 250, value);
+      badusage(_("unknown force/refuse option `%.*s'"), l<250 ? l : 250, value);
     *fip->opt= cip->arg;
     if (!comma) break;
     value= ++comma;
@@ -295,32 +321,34 @@ static const struct cmdinfo cmdinfos[]= {
    */
 #define ACTION(longopt,shortopt,code,function) \
  { longopt, shortopt, 0,0,0, setaction, code, 0, (voidfnp)function }
-  ACTION( "install",                        'i', act_install,       archivefiles    ),
-  ACTION( "unpack",                          0,  act_unpack,        archivefiles    ),
-  ACTION( "record-avail",                   'A', act_avail,         archivefiles    ),
-  ACTION( "configure",                       0,  act_configure,     packages        ),
-  ACTION( "remove",                         'r', act_remove,        packages        ),
-  ACTION( "purge",                           0,  act_purge,         packages        ),
+  ACTION( "install",                        'i', act_install,              archivefiles    ),
+  ACTION( "unpack",                          0,  act_unpack,               archivefiles    ),
+  ACTION( "record-avail",                   'A', act_avail,                archivefiles    ),
+  ACTION( "configure",                       0,  act_configure,            packages        ),
+  ACTION( "remove",                         'r', act_remove,               packages        ),
+  ACTION( "purge",                          'P', act_purge,                packages        ),
   ACTION( "listfiles",                      'L', act_listfiles,     enqperpackage   ),
-  ACTION( "status",                         's', act_status,        enqperpackage   ),
-  ACTION( "get-selections",                  0,  act_getselections, getselections   ),
-  ACTION( "set-selections",                  0,  act_setselections, setselections   ),
-  ACTION( "print-avail",                     0,  act_printavail,    enqperpackage   ),
-  ACTION( "update-avail",                    0,  act_avreplace,     updateavailable ),
-  ACTION( "merge-avail",                     0,  act_avmerge,       updateavailable ),
-  ACTION( "clear-avail",                     0,  act_avclear,       updateavailable ),
-  ACTION( "forget-old-unavail",              0,  act_forgetold,     forgetold       ),
-  ACTION( "audit",                          'C', act_audit,         audit           ),
-  ACTION( "yet-to-unpack",                   0,  act_unpackchk,     unpackchk       ),
-  ACTION( "list",                           'l', act_listpackages,  listpackages    ),
-  ACTION( "search",                         'S', act_searchfiles,   searchfiles     ),
-  ACTION( "print-architecture",              0,  act_printarch,     printarch       ),
-  ACTION( "print-gnu-build-architecture",    0,  act_printgnuarch,  printarch       ),
-  ACTION( "assert-support-predepends",       0,  act_assertpredep,  assertpredep    ),
-  ACTION( "assert-working-epoch",            0,  act_assertepoch,   assertepoch     ),
-  ACTION( "print-installation-architecture", 0,  act_printinstarch, printinstarch   ),
-  ACTION( "predep-package",                  0,  act_predeppackage, predeppackage   ),
-  ACTION( "compare-versions",                0,  act_cmpversions,   cmpversions     ),
+  ACTION( "status",                         's', act_status,               enqperpackage   ),
+  ACTION( "get-selections",                  0,  act_getselections,        getselections   ),
+  ACTION( "set-selections",                  0,  act_setselections,        setselections   ),
+  ACTION( "print-avail",                    'p', act_printavail,           enqperpackage   ),
+  ACTION( "update-avail",                    0,  act_avreplace,            updateavailable ),
+  ACTION( "merge-avail",                     0,  act_avmerge,              updateavailable ),
+  ACTION( "clear-avail",                     0,  act_avclear,              updateavailable ),
+  ACTION( "forget-old-unavail",              0,  act_forgetold,            forgetold       ),
+  ACTION( "audit",                          'C', act_audit,                audit           ),
+  ACTION( "yet-to-unpack",                   0,  act_unpackchk,            unpackchk       ),
+  ACTION( "list",                           'l', act_listpackages,         listpackages    ),
+  ACTION( "search",                         'S', act_searchfiles,          searchfiles     ),
+  ACTION( "print-architecture",              0,  act_printarch,            printarch       ),
+  ACTION( "print-gnu-build-architecture",    0,  act_printgnuarch,         printarch       ),
+  ACTION( "assert-support-predepends",       0,  act_assertpredep,         assertpredep    ),
+  ACTION( "assert-working-epoch",            0,  act_assertepoch,          assertepoch     ),
+  ACTION( "assert-long-filenames",           0,  act_assertlongfilenames,  assertlongfilenames ),
+  ACTION( "assert-multi-conrep",             0,  act_assertmulticonrep,    assertmulticonrep ),
+  ACTION( "print-installation-architecture", 0,  act_printinstarch,        printinstarch   ),
+  ACTION( "predep-package",                  0,  act_predeppackage,        predeppackage   ),
+  ACTION( "compare-versions",                0,  act_cmpversions,          cmpversions     ),
   
   { "pending",           'a',  0,  &f_pending,     0,  0,             1              },
   { "recursive",         'R',  0,  &f_recursive,   0,  0,             1              },
@@ -333,6 +361,7 @@ static const struct cmdinfo cmdinfos[]= {
   { "largemem",           0,   0,  &f_largemem,    0,  0,             1              },
   { "smallmem",           0,   0,  &f_largemem,    0,  0,            -1              },
   { "root",               0,   1,  0, 0,               setroot                       },
+  { "abort-after",        0,   1,  &errabort,      0,  setinteger,    0              },
   { "admindir",           0,   1,  0, &admindir,       0                             },
   { "instdir",            0,   1,  0, &instdir,        0                             },
   { "ignore-depends",     0,   1,  0, 0,               ignoredepends                 },
@@ -349,7 +378,7 @@ static const struct cmdinfo cmdinfos[]= {
 
 static void execbackend(int argc, const char *const *argv) {
   execvp(BACKEND, (char* const*) argv);
-  ohshite("failed to exec " BACKEND);
+  ohshite(_("failed to exec dpkg-deb"));
 }
 
 int main(int argc, const char *const *argv) {
@@ -358,13 +387,17 @@ int main(int argc, const char *const *argv) {
   const char *argp, *const *blongopts, *const *argvs;
   static void (*actionfunction)(const char *const *argv);
 
+  setlocale(LC_ALL, "");
+  bindtextdomain(PACKAGE, LOCALEDIR);
+  textdomain(PACKAGE);
+
   if (setjmp(ejbuf)) { /* expect warning about possible clobbering of argv */
     error_unwind(ehflag_bombout); exit(2);
   }
   push_error_handler(&ejbuf,print_error_fatal,0);
 
   umask(022); /* Make sure all our status databases are readable. */
-  
+ 
   for (argvs=argv+1; (argp= *argvs) && *argp++=='-'; argvs++) {
     if (*argp++=='-') {
       if (!strcmp(argp,"-")) break;
@@ -381,7 +414,7 @@ int main(int argc, const char *const *argv) {
   }
 
   myopt(&argv,cmdinfos);
-  if (!cipaction) badusage("need an action option");
+  if (!cipaction) badusage(_("need an action option"));
 
   setvbuf(stdout,0,_IONBF,0);
   filesdbinit();
