@@ -53,7 +53,8 @@ enum action { act_unset, act_install, act_unpack, act_avail, act_configure,
               act_unpackchk, act_status, act_searchfiles, act_audit, act_listfiles,
               act_assertpredep, act_printarch, act_predeppackage, act_cmpversions,
               act_printinstarch, act_compareversions, act_printavail, act_avclear,
-              act_forgetold, act_getselections, act_setselections, act_printgnuarch };
+              act_forgetold, act_getselections, act_setselections, act_printgnuarch,
+              act_assertepoch, act_assertlongfilenames, act_assertmulticonrep };
 
 enum conffopt {
   cfof_prompt        =     001,
@@ -82,8 +83,10 @@ extern unsigned long f_debug;
 extern int fc_downgrade, fc_configureany, fc_hold, fc_removereinstreq, fc_overwrite;
 extern int fc_removeessential, fc_conflicts, fc_depends, fc_dependsversion;
 extern int fc_autoselect, fc_badpath, fc_overwritediverted, fc_architecture;
-extern int fc_nonroot, fc_overwritedir;
+extern int fc_nonroot, fc_overwritedir, fc_conff_new, fc_conff_miss;
+extern int fc_conff_old, fc_conff_def;
 
+extern int errabort;
 extern const char *admindir;
 extern const char *instdir;
 extern struct packageinlist *ignoredependss;
@@ -97,6 +100,7 @@ void filesdbinit(void);
 
 void archivefiles(const char *const *argv);
 void process_archive(const char *filename);
+int wanttoinstall(struct pkginfo *pkg, const struct versionrevision *ver, int saywhy);
 
 /* from update.c */
 
@@ -110,7 +114,10 @@ void audit(const char *const *argv);
 void unpackchk(const char *const *argv);
 void searchfiles(const char *const *argv);
 void enqperpackage(const char *const *argv);
+void assertepoch(const char *const *argv);
 void assertpredep(const char *const *argv);
+void assertlongfilenames(const char *const *argv);
+void assertmulticonrep(const char *const *argv);
 void predeppackage(const char *const *argv);
 void printarch(const char *const *argv);
 void printinstarch(const char *const *argv);
@@ -161,11 +168,14 @@ void cu_closefd(int argc, void **argv);
 
 int ignore_depends(struct pkginfo *pkg);
 int force_depends(struct deppossi *possi);
+int force_conff_new(struct deppossi *possi);
+int force_conff_miss(struct deppossi *possi);
 int force_conflicts(struct deppossi *possi);
 void ensure_package_clientdata(struct pkginfo *pkg);
 const char *pkgadminfile(struct pkginfo *pkg, const char *whichfile);
 void oldconffsetflags(struct conffile *searchconff);
 void ensure_pathname_nonexisting(const char *pathname);
+int chmodsafe_unlink(const char *pathname); /* chmod 600, then unlink */
 void checkpath(void);
 struct filenamenode *namenodetouse(struct filenamenode*, struct pkginfo*);
 
@@ -195,6 +205,7 @@ enum debugflags {
 };
   
 void debug(int which, const char *fmt, ...) PRINTFFORMAT(2,3);
+void check_libver(void);
 
 /* from depcon.c */
 
