@@ -14,11 +14,13 @@ version 2 or later for copying conditions.  There is NO warranty.
 Usage: dpkg-buildpackage [options]
 Options: -r<gain-root-command>
          -p<sign-command>
+	 -k<keyid>     the key to use for signing
          -sgpg         the sign-command is called like GPG
          -spgp         the sign-command is called like PGP 
+         -sdebsign     the sign-command works like debsign
          -us           unsigned source
          -uc           unsigned changes
-         -a<arch>      architecture field of the changes _file_name_
+         -a<arch>      Debian architecture we build for
          -b            binary-only, do not build source } also passed to
          -B            binary-only, no arch-indep files } dpkg-genchanges
          -v<version>   changes since version <version>      }
@@ -29,23 +31,22 @@ Options: -r<gain-root-command>
          -sd           uploaded src is diff and .dsc only   }
          -nc           do not clean source tree (implies -b)
          -tc           clean source tree when finished
+         -ap           add pause before starting signature process
          -h            print this message
+         -i[<regex>]   ignore diffs of files matching regex } only passed
+                                                             to dpkg-source
 END
 }
 
 rootcommand=''
-signcommand=pgp # Default command for signing
-warnpgp='no'	# Display a warning to encourage switching to gpg?
-if [ ! -e $HOME/.gnupg/secring.gpg ] ; then
-	warnpgp=yes
-fi
-if [ -e $HOME/.gnupg/secring.gpg -a ! -e $HOME/.pgp/secring.pgp ] ; then
+signcommand=""
+if [ -e $GNUPGHOME/secring.pgp -o -e $HOME/.gnupg/secring.gpg ] && \
+		command -v gpg > /dev/null 2>&1; then
 	signcommand=gpg
-fi
-if [ -e $HOME/.pgp/secring.pgp -a ! -e $HOME/.gnupg/secring.gpg ] ; then
+elif command -v pgp > /dev/null 2>&1 ; then
 	signcommand=pgp
 fi
-signinterface=$signcommand
+
 signsource='withecho signfile'
 signchanges='withecho signfile'
 cleansource=false
@@ -56,6 +57,7 @@ since=''
 maint=''
 desc=''
 noclean=false
+usepause=false
 
 while [ $# != 0 ]
 do
@@ -63,17 +65,22 @@ do
 	case "$1" in
 	-h)	usageversion; exit 0 ;;
 	-r*)	rootcommand="$value" ;;
-	-p*)	signcommand="$value"; warnpgp='' ;;
-	-sgpg)  signinterface=gpg ;;
-	-spgp)  signinterface=pgp ;;
-	-us)	signsource=: ; warnpgp='' ;;
-	-uc)	signchanges=: ; warnpgp='' ;;
+	-p*)	signcommand="$value" ;;
+	-k*)	signkey="$value" ;;
+	-sgpg)  forcesigninterface=gpg ;;
+	-spgp)  forcesigninterface=pgp ;;
+	-sdebsign)  forcesigninterface=debsign ;;
+	-us)	signsource=: ;;
+	-uc)	signchanges=: ;;
+	-ap)	usepause="true";;
 	-a*)    opt_a=1; arch="$value" ;;
 	-si)	sourcestyle=-si ;;
 	-sa)	sourcestyle=-sa ;;
 	-sd)	sourcestyle=-sd ;;
+        -i*)    diffignore=$1;;
 	-tc)	cleansource=true ;;
-	-nc)	noclean=true; binaryonly=-b ;;
+	-t*)    targetgnusystem="$value" ;;          # Order DOES matter!
+	-nc)	noclean=true; if [ -z "$binaryonly" ]; then binaryonly=-b; fi ;;
 	-b)	binaryonly=-b ;;
 	-B)	binaryonly=-B; binarytarget=binary-arch ;;
 	-v*)	since="$value" ;;
@@ -85,12 +92,18 @@ do
 	shift
 done
 
-if test "X$warnpgp" = "Xyes" ; then
-  echo >&2 <<EOWARN
-The Debian project will switch to using GPG (the GNU Privacy Guard) instead
-of PGP for signing packages. You might want to make preparations. Check out
-the gnupg and debian-keyring packages.
-EOWARN
+if [ -z "$signcommand"  ] ; then
+	signsource=:
+	signchanges=:
+fi
+
+if test -n "$forcesigninterface" ; then
+  signinterface=$forcesigninterface
+else
+  signinterface=$signcommand
+fi
+if test "$signinterface" = "debsign"; then
+	signsource=:
 fi
 
 mustsetvar () {
@@ -109,7 +122,10 @@ mustsetvar package "`dpkg-parsechangelog | sed -n 's/^Source: //p'`" "source pac
 mustsetvar version "`dpkg-parsechangelog | sed -n 's/^Version: //p'`" "source version"
 if [ -n "$maint" ]; then maintainer="$maint"; 
 else mustsetvar maintainer "`dpkg-parsechangelog | sed -n 's/^Maintainer: //p'`" "source maintainer"; fi
+command -v dpkg-architecture > /dev/null 2>&1 && eval `dpkg-architecture -a${arch} -t${targetgnusystem} -s`
+archlist=`dpkg-architecture -a${arch} -t${targetgnusystem} -f 2> /dev/null`
 test "${opt_a}" \
+	|| arch=`dpkg-architecture -a${arch} -t${targetgnusystem} -qDEB_HOST_ARCH 2> /dev/null` && test "${arch}" \
 	|| mustsetvar arch "`dpkg --print-architecture`" "build architecture"
 
 sversion=`echo "$version" | perl -pe 's/^\d+://'`
@@ -117,15 +133,19 @@ pv="${package}_${sversion}"
 pva="${package}_${sversion}${arch:+_${arch}}"
 
 signfile () {
-	if test $signinterface = gpg ; then
-		# --textmode doesn't seem to work; we use perl to filter ^M;
-		# this doesn't affect the actual signature.
+	if test "$signinterface" = "gpg" ; then
 		(cat "../$1" ; echo "") | \
-		$signcommand --local-user "$maintainer" --clearsign --armor \
-			--textmode --output - - | \
-			perl -n -p -e 's/\r$//' > "../$1.asc" 
+		$signcommand --local-user "${signkey:-$maintainer}" --clearsign --armor \
+			--textmode  > "../$1.asc" 
+	elif test "$signinterface" = "debsign"; then
+		if test x$signkey != x; then
+			$signcommand -k"$signkey" ../$1
+		else
+			$signcommand ../$1
+		fi
+		return
 	else
-		$signcommand -u "$maintainer" +clearsig=on -fast <"../$1" \
+		$signcommand -u "${signkey:-$maintainer}" +clearsig=on -fast <"../$1" \
 			>"../$1.asc"
 	fi
 	echo
@@ -143,13 +163,19 @@ if [ -n "$since"	]; then set -- "$@" "-v$since"		; fi
 if [ -n "$desc"		]; then set -- "$@" "-C$desc"		; fi
 
 if [ x$noclean != xtrue ]; then
-	withecho $rootcommand debian/rules clean
+	withecho $rootcommand debian/rules clean $archlist
 fi
 if [ x$binaryonly = x ]; then
-	cd ..; withecho dpkg-source -b "$dirn"; cd "$dirn"
+	cd ..; withecho dpkg-source $diffignore -b "$dirn"; cd "$dirn"
 fi
-withecho debian/rules build
-withecho $rootcommand debian/rules $binarytarget
+withecho debian/rules build $archlist
+withecho $rootcommand debian/rules $binarytarget $archlist
+
+if [ "$usepause" = "true" ] && [ x$binaryonly = x -o x$signchanges != x ] ; then
+    echo Press the return key to start signing process
+    read dummy_stuff
+fi
+
 if [ x$binaryonly = x ]; then
         $signsource "$pv.dsc"
 fi
@@ -177,7 +203,7 @@ fi
 $signchanges "$pva.changes"
 
 if $cleansource; then
-	withecho $rootcommand debian/rules clean
+	withecho $rootcommand debian/rules clean $archlist
 fi
 
 echo "dpkg-buildpackage: $srcmsg"
