@@ -2,27 +2,36 @@
 
 #use POSIX; &ENOENT;
 sub ENOENT { 2; }
-# Sorry about this, but POSIX.pm isn't necessarily available
+# Sorry about this, but the errno-part of POSIX.pm isn't in perl-*-base
 
 $version= '1.0.11'; # This line modified by Makefile
-sub usageversion {
-    print(STDERR <<END)
-Debian GNU/Linux dpkg-divert $version.  Copyright (C) 1995
-Ian Jackson.  This is free software; see the GNU General Public Licence
-version 2 or later for copying conditions.  There is NO warranty.
+sub showversion {
+    print("Debian GNU/Linux dpkg-divert $version.\n") || &quit("failed to write version: $!");
+}
+
+sub usage {
+    &showversion;
+    print(STDOUT <<END)
+Copyright (C) 1995 Ian Jackson.  This is free software; see the GNU General
+Public Licence version 2 or later for copying conditions. There is NO warranty.
 
 Usage:
- dpkg-divert [options] [--add] <file>
- dpkg-divert [options] --remove <file>
- dpkg-divert [options] --list [<glob-pattern>]
 
-Options:  --package <package> | --local  --divert <divert-to>  --rename
-          --quiet  --test  --help|--version  --admindir <directory>
+ dpkg-divert [options] [--add] <file>               - add a diversion
+ dpkg-divert [options] --remove <file>              - remove the diversion
+ dpkg-divert [options] --list [<glob-pattern>]      - show file diversions
 
-<package> is the name of a package whose copy of <file> will not be diverted.
-<divert-to> is the name used by other packages' versions.
---local specifies that all packages' versions are diverted.
---rename causes dpkg-divert to actually move the file aside (or back).
+Options: 
+    --package <package>        name of the package whose copy of <file>
+                               will not be diverted.
+    --local                    all packages' versions are diverted.
+    --divert <divert-to>       the name used by other packages' versions.
+    --rename                   actually move the file aside (or back).
+    --quiet                    quiet operation, minimal output
+    --test                     don't do anything, just demonstrate
+    --help                     print this help screen and exit
+    --version                  output version and exit
+    --admindir <directory>     set the directory with the diversions file
 
 When adding, default is --local and --divert <original>.distrib.
 When removing, --package or --local and --divert must match if specified.
@@ -48,8 +57,10 @@ while (@ARGV) {
     last if m/^--$/;
     if (!m/^-/) {
         unshift(@ARGV,$_); last;
-    } elsif (m/^--(help|version)$/) {
-        &usageversion; exit(0);
+    } elsif (m/^--help$/) {
+        &usage; exit(0);
+    } elsif (m/^--version$/) {
+        &showversion; exit(0);
     } elsif (m/^--test$/) {
         $testmode= 1;
     } elsif (m/^--rename$/) {
@@ -180,6 +191,23 @@ sub checkrename {
         &quit("cannot stat old name \`$rsrc': $!");
     (@sdest= lstat($rdest)) || $! == &ENOENT ||
         &quit("cannot stat new name \`$rdest': $!");
+    # Unfortunately we have to check for write access in both
+    # places, just having +w is not enough, since people do
+    # mount things RO, and we need to fail before we start
+    # mucking around with things. So we open a file with the
+    # same name as the diversions but with an extension that
+    # (hopefully) wont overwrite anything. If it succeeds, we
+    # assume a writable filesystem.
+    foreach $file ($rsrc,$rdest) {
+	open (TMP, ">> ${file}.dpkg-devert.tmp") || $! == ENOENT ||
+		&quit("error checking \`$file': $!");
+	close TMP;
+	if ($1 == ENOENT) {
+		$dorename = 0;
+	} else {
+		unlink ("${file}.dpkg-devert.tmp");
+	}
+    }
     if (@ssrc && @sdest &&
         !($ssrc[0] == $sdest[0] && $ssrc[1] == $sdest[1])) {
         &quit("rename involves overwriting \`$rdest' with\n".
@@ -220,5 +248,5 @@ sub infoa { &infol($file,$divertto,$package); }
 sub infon { &infol($contest[$i],$altname[$i],$package[$i]); }
 
 sub quit { print STDERR "dpkg-divert: @_\n"; exit(2); }
-sub badusage { print STDERR "dpkg-divert: @_\n\n"; &usageversion; exit(2); }
+sub badusage { print STDERR "dpkg-divert: @_\n\n"; print("You need --help.\n"); exit(2); }
 sub badfmt { &quit("internal error: $admindir/diversions corrupt: $_[0]"); }
